@@ -34,6 +34,7 @@ class Plugin(Plugin_Base):
         self.logger.i("-- plugin <{}> init".format(self.name))
         self.logger.i("-- plugin <{}> config: {}".format(self.name, self.config))
         self._extention = {
+            # we not need TOC, but we use this extension to generate ID of headers
             "toc" : {
                 "depth": config["toc_depth"] if "toc_depth" in config else 3
             },
@@ -96,7 +97,8 @@ class Plugin(Plugin_Base):
                         "keywords": keywords,
                         "tags": tags,
                         "body": html,
-                        "toc": html.toc_html if html.toc_html else "",
+                        # "toc": html.toc_html if html.toc_html else "",
+                        "toc": "", # just empty, toc generated by js but not python
                         "metadata": html.metadata,
                         "raw": content
                     }
